Wrapper around base r `t()` that returns a tibble. Transposes a data frame, intended for use on the output of a dplyr::summarize operation
pivot_summary(sumr, ...)a tibble
for an ungrouped summarize, ... argument can be left empty for a grouped summarize, use column names or tidyselect to pivot the group names. Multiple groups will be concatenated before pivoting.